@@ -1,32 +1,32 @@
-"""Registry of agent names for `rllib train --run=<alg_name>`"""
+"""Registry of agents as trainables for Tune."""
 
 
 def _import_naf():
-    from raylab.agents.naf.naf import NAFTrainer
+    from raylab.agents.naf import NAFTrainer
 
     return NAFTrainer
 
 
 def _import_svg_inf():
-    from raylab.agents.svg import SVGInfTrainer
+    from raylab.agents.svg.inf import SVGInfTrainer
 
     return SVGInfTrainer
 
 
 def _import_svg_one():
-    from raylab.agents.svg import SVGOneTrainer
+    from raylab.agents.svg.one import SVGOneTrainer
 
     return SVGOneTrainer
 
 
 def _import_sac():
-    from raylab.agents.sac.sac import SACTrainer
+    from raylab.agents.sac import SACTrainer
 
     return SACTrainer
 
 
 def _import_sop():
-    from raylab.agents.sop.sop import SOPTrainer
+    from raylab.agents.sop import SOPTrainer
 
     return SOPTrainer
 
@@ -38,23 +38,29 @@ def _import_mapo():
 
 
 def _import_trpo():
-    from raylab.agents.trpo.trpo import TRPOTrainer
+    from raylab.agents.trpo import TRPOTrainer
 
     return TRPOTrainer
 
 
 def _import_soft_svg():
-    from raylab.agents.svg import SoftSVGTrainer
+    from raylab.agents.svg.soft import SoftSVGTrainer
 
     return SoftSVGTrainer
 
 
 def _import_acktr():
-    from raylab.agents.acktr.acktr import ACKTRTrainer
+    from raylab.agents.acktr import ACKTRTrainer
 
     return ACKTRTrainer
 
 
+def _import_mbpo():
+    from raylab.agents.mbpo import MBPOTrainer
+
+    return MBPOTrainer
+
+
 AGENTS = {
     "NAF": _import_naf,
     "SVG(inf)": _import_svg_inf,
@@ -65,4 +71,5 @@ AGENTS = {
     "TRPO": _import_trpo,
     "SoftSVG": _import_soft_svg,
     "ACKTR": _import_acktr,
+    "MBPO": _import_mbpo,
 }
