@@ -3,8 +3,8 @@ import numpy as np
 import pytest
 import torch
 
+from raylab.envs import get_reward_fn
 from raylab.envs.registry import ENVS
-from raylab.envs.rewards import get_reward_fn
 from raylab.envs.rewards import REWARDS
 
 
